@@ -5,16 +5,10 @@ class Audio:
         self.volume = volume
 
         mixer.Sound(file)
-        mixer.Sound.set_volume(volume)
+        mixer.Sound.set_volume(self.volume)
 
     def play(self):
         mixer.Sound.play()
-    
-    def pause(self):
-        mixer.Sound.pause()
-
-    def resume(self):
-        mixer.Sound.unpause()
 
     def stop(self):
-        mixer.Sound.stop()
\ No newline at end of file
+        mixer.Sound.stop()
