@@ -1,3 +1,4 @@
+import time
 import pygame
 from mandaw.input import Controls
 
@@ -13,7 +14,7 @@ class Mandaw:
         pygame.init()
         self.clock = pygame.time.Clock()
 
-        self.dt = 0
+        self.dt = self.clock.tick(self.fps) / 1000
 
         self.window = pygame.display.set_mode((self.width, self.height))
         pygame.display.set_caption(self.title)
